@@ -4,10 +4,11 @@ from copy import deepcopy
 from datetime import datetime
 from math import ceil
 from random import choice, randint, uniform
+import warnings
 
 from .consts import MAX_LABEL_COST, SMALL_DIVISOR
 from .path import find_path_for_agents, find_shortest_path, \
-                  single_source_shortest_path
+                  single_source_shortest_path, benchmark_apsp
 
 
 __all__ = ['UI']
@@ -256,21 +257,6 @@ class Agent:
     def get_dp_id(self):
         return self.dp_id
 
-    def _initialize_simu(self, start_time, duration, interval, loading_profile):
-        try:
-            num = len(self.link_path)
-            self.curr_link_pos = num - 1
-            self.link_arr_interval = [-1] * num
-            self.link_dep_interval = [-1] * num
-            if loading_profile.startswith('random'):
-                # randomly set up departure time
-                self.dep_time = randint(0, duration - 1) + start_time
-            elif loading_profile.startswith('constant'):
-                self.dep_time = start_time
-            self.link_arr_interval[-1] = (self.dep_time - start_time) * 60 // interval
-        except ZeroDivisionError:
-            raise Exception('Simulation Resolution is Zero! Check settings.yml')
-
     def update_dep_time(self, tt):
         self.link_dep_interval[self.curr_link_pos] = (
             self.link_arr_interval[self.curr_link_pos] + tt
@@ -1530,6 +1516,9 @@ class Assignment:
         return find_shortest_path(self.network, from_node_id,
                                   to_node_id, seq_type)
 
+    def benchmark_apsp(self):
+        benchmark_apsp(self.network)
+
     def perform_network_assignment(self, assignment_mode,
                                    iter_num, column_update_num):
         # perform_network_assignment(assignment_mode, iter_num, column_update_num)
@@ -1657,29 +1646,63 @@ class Assignment:
         return self.simu_st
 
     def initialize_simulation(self, loading_profile):
-        agents = self.network.agents
-        links = self.network.links
+        profiles = ['constant', 'random', 'uniform']
+        if loading_profile not in profiles:
+            Warning.warn(
+                f'{loading_profile} is not supported!'
+                ' constant loading profile will be adopted.'
+            )
 
-        for a in agents:
-            if a.get_node_path() is None:
+        agent_id = 1
+        links = self.get_links()
+        column_pool = self.get_column_pool()
+
+        for k, cv in column_pool.items():
+            if cv.get_od_volume() <= 0:
                 continue
 
-            a._initialize_simu(
-                self.simu_st, self.simu_dur,
-                self.simu_rez, loading_profile
-            )
-            i = a.get_origin_dep_interval()
-            if i not in self.network.td_agents.keys():
-                self.network.td_agents[i] = []
-            self.network.td_agents[i].append(a.get_seq_no())
-            # set up link volume
-            for x in a.link_path:
-                link = links[x]
-                if link.length == 0:
+            # k= (at, dp, orig, dest)
+            at = k[0]
+            dp = k[1]
+            oz = k[2]
+            dz = k[3]
+
+            for col in cv.get_columns():
+                if col.nodes is None:
                     continue
 
-                link.reset_period_flow_vol(0)
-                link.increase_period_flow_vol(0, a.PCE_factor)
+                # link volume is already set up in UE
+                vol = ceil(col.get_volume())
+                for j in range(vol):
+                    agent = Agent(agent_id, agent_id - 1, at, dp, oz, dz)
+
+                    n = col.get_link_num()
+                    agent.curr_link_pos = n - 1
+                    agent.link_arr_interval = [-1] * n
+                    agent.link_dep_interval = [-1] * n
+
+                    # constant departure time by default
+                    t = self.simu_st
+                    if loading_profile.startswith('uniform'):
+                        t += int(j / col.get_volume() * self.simu_dur)
+                    elif loading_profile.startswith('random'):
+                        t += randint(0, self.simu_dur - 1)
+
+                    # simulation interval
+                    i = (t - self.simu_st) * 60 // self.simu_rez
+                    agent.link_arr_interval[-1] = i
+                    agent.dep_time = t
+
+                    # set up node path and link path
+                    agent.link_path = [x for x in col.links]
+                    agent.node_path = [x for x in col.nodes]
+                    agent.path_cost = col.get_distance()
+                    if i not in self.network.td_agents.keys():
+                        self.network.td_agents[i] = []
+                    self.network.td_agents[i].append(agent.get_seq_no())
+                    self.network.agents.append(agent)
+
+                    agent_id += 1
 
         # replicate _update_link_travel_time_and_cost()
         for link in links:
@@ -1896,4 +1919,7 @@ class UI:
         link_strs = ';'.join(str(x) for x in links)
 
         print(f'number of accessible links is {len(links)}')
-        print(f'accessible links are: {link_strs}')
\ No newline at end of file
+        print(f'accessible links are: {link_strs}')
+
+    def benchmark_apsp(self):
+        self._base_assignment.benchmark_apsp()
\ No newline at end of file
